*-----------------------------------------------------------------------
      SUBROUTINE SGTNXU(N,UPX,UPY,ITPAT,ICOLOR)

      REAL      UPX(*),UPY(*)
      LOGICAL   LFCATR
      INTEGER    ITPATX

      CALL SWQFCC(LFCATR)
      IF(.NOT.LFCATR) THEN
        CALL MSGDMP('M','SGTNXU','FULL COLOR MODE IS NOT SUPPORTED.')
      END IF

      IF (N.LT.3) THEN
        CALL MSGDMP('E','SGTNXU','NUMBER OF POINTS IS LESS THAN 3.')
      END IF
      IF (ITPAT.EQ.0) THEN
        CALL MSGDMP('M','SGTNXU','TONE PAT. INDEX IS 0 / DO NOTHING.')
        RETURN
      END IF
      IF (ITPAT.LT.0) THEN
        CALL MSGDMP('E','SGTNXU','TONE PAT. INDEX IS LESS THAN 0.')
      END IF

      CALL SWSFCM(.TRUE.)
      CALL SWSTCL(ICOLOR)
      CALL SWSLCL(ICOLOR)


      ITPATX=999*1000+MOD(ITPAT,1000)
      CALL SZTNOP(ITPATX)
      CALL SZTNZU(N,UPX,UPY)
      CALL SZTNCL

      CALL SWSFCM(.FALSE.)

      END
